@@ -1270,7 +1270,9 @@ class Slice(FusedNode):
                     if i == 2:
                         x = x[:, :, starts[index]:ends[index], ...]
                     if i == 3:
-                        x = x[:, :, starts[index]:ends[index], ...]
+                        x = x[:, :, :, starts[index]:ends[index], ...]
+                    if i == 4:
+                        x = x[:, :, :, :, starts[index]:ends[index], ...]
                     index += 1
             return [x]
         if len(intensors) == 5:
@@ -1291,6 +1293,8 @@ class Slice(FusedNode):
                         x = x[:, :, starts[index]:ends[index]:steps[index], ...]
                     if i == 3:
                         x = x[:, :, :, starts[index]:ends[index]:steps[index], ...]
+                    if i == 4:
+                        x = x[:, :, :, :, starts[index]:ends[index]:steps[index], ...]
                     index += 1
             return [x]
         if len(intensors) == 1:
@@ -1306,7 +1310,9 @@ class Slice(FusedNode):
                     if i == 2:
                         x = x[:, :, self.starts[index]:self.ends[index], ...]
                     if i == 3:
-                        x = x[:, :, self.starts[index]:self.ends[index], ...]
+                        x = x[:, :, :, self.starts[index]:self.ends[index], ...]
+                    if i == 4:
+                        x = x[:, :, :, :, self.starts[index]:self.ends[index], ...]
                     index += 1
             return [x]
 
